==> devextreme-23.1.2-beta.tgz: package/cjs/integration/jquery/component_registrator.js <==
/**
 * DevExtreme (cjs/integration/jquery/component_registrator.js)
 * Version: 23.1.2
 * Build date: Wed May 17 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _jquery = _interopRequireDefault(require("jquery"));
var _component_registrator_callbacks = _interopRequireDefault(require("../../core/component_registrator_callbacks"));
var _errors = _interopRequireDefault(require("../../core/errors"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
if (_jquery.default) {
    var registerJQueryComponent = function(name, componentClass) {
        _jquery.default.fn[name] = function(options) {
            var isMemberInvoke = "string" === typeof options;
            var result;
            if (isMemberInvoke) {
                var memberName = options;
                var memberArgs = [].slice.call(arguments).slice(1);
                this.each((function() {
                    var instance = componentClass.getInstance(this);
                    if (!instance) {
                        throw _errors.default.Error("E0009", name)
                    }
                    var member = instance[memberName];
                    var memberValue = member.apply(instance, memberArgs);
                    if (void 0 === result) {
                        result = memberValue
                    }
                }))
            } else {
                this.each((function() {
                    var instance = componentClass.getInstance(this);
                    if (instance) {
                        instance.option(options)
                    } else {
                        new componentClass(this, options)
                    }
                }));
                result = this
            }
            return result
        }
    };
    _component_registrator_callbacks.default.add(registerJQueryComponent)
}

==> devextreme-23.2.2-beta.tgz: package/cjs/integration/jquery/component_registrator.js <==
/**
 * DevExtreme (cjs/integration/jquery/component_registrator.js)
 * Version: 23.2.2
 * Build date: Fri Nov 10 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _jquery = _interopRequireDefault(require("jquery"));
var _component_registrator_callbacks = _interopRequireDefault(require("../../core/component_registrator_callbacks"));
var _errors = _interopRequireDefault(require("../../core/errors"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
if (_jquery.default) {
    const registerJQueryComponent = function(name, componentClass) {
        _jquery.default.fn[name] = function(options) {
            const isMemberInvoke = "string" === typeof options;
            let result;
            if (isMemberInvoke) {
                const memberName = options;
                const memberArgs = [].slice.call(arguments).slice(1);
                this.each((function() {
                    const instance = componentClass.getInstance(this);
                    if (!instance) {
                        throw _errors.default.Error("E0009", name)
                    }
                    const member = instance[memberName];
                    const memberValue = member.apply(instance, memberArgs);
                    if (void 0 === result) {
                        result = memberValue
                    }
                }))
            } else {
                this.each((function() {
                    const instance = componentClass.getInstance(this);
                    if (instance) {
                        instance.option(options)
                    } else {
                        new componentClass(this, options)
                    }
                }));
                result = this
            }
            return result
        }
    };
    _component_registrator_callbacks.default.add(registerJQueryComponent)
}
